@@ -1,15 +1,13 @@
 from hashlib import sha1
 from normality import stringify
 
+NULL_ORIGIN = "null"
+
 
 class StoreException(Exception):
     pass
 
 
-class DroppedException(StoreException):
-    pass
-
-
 def safe_fragment(fragment):
     """Make a hashed fragement."""
     fragment = stringify(fragment)
